##  KPI Breakdown
To view breakdown data for a KPI, select it on the dashboard. In the overlay that appears, use the **Pivot by** filter to segment KPI results by the categories you've created, such as business units, teams, or regions. By analyzing KPI data across different segments, you can pinpoint specific areas that may require attention or improvement.
For example, the KPI “Technical fit of applications“ in the image below shows how it performs across various teams and business units. When a KPI reaches 100%, it indicates that no improvements are needed.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio9d6fae54c4d44d6c8fec85bedabe711a_LowRes.png)
KPI Breakdown
